@@ -19,6 +19,7 @@ from .autoresolve import Autoresolve
 from .skip_constraint_comments import SkipConstraintComments
 from .live_output import LiveOutput
 from .extra_index_url import ExtraIndexUrl
+from .build_isolation import BuildIsolation
 
 
 class FeaturesController:
@@ -44,6 +45,7 @@ class FeaturesController:
         self.skip_constraint_comments = SkipConstraintComments()
         self.live_output = LiveOutput()
         self.extra_index_url = ExtraIndexUrl()
+        self.build_isolation = BuildIsolation()
         self._features = [
             self.annotate_index,
             self.use_cache,
@@ -63,6 +65,7 @@ class FeaturesController:
             self.skip_constraint_comments,
             self.live_output,
             self.extra_index_url,
+            self.build_isolation,
         ]
 
     def bind(self, command):
